@@ -3,13 +3,12 @@
 require('mocha');
 var assert = require('assert');
 var forOwn = require('for-own');
-var negations = require('./negations');
 var matcher = require('./support/matcher');
+var negations = require('./_negations');
 
 describe('running extglob against minimatch tests', function() {
   forOwn(negations, function(val, fixture) {
-    if (fixture !== 'asd.js.xyz') return;
-
+    if (fixture !== 'asd.jss.xyz') return
     describe('"' + fixture + '"', function() {
       forOwn(val, function(expected, pattern) {
         var exp = expected === false ? ' not' : '';
@@ -17,7 +16,7 @@ describe('running extglob against minimatch tests', function() {
         it('should' + exp + ' match "' + pattern + '"', function() {
           var actual = matcher.isMatch(fixture, pattern);
           if (actual === null) return;
-          assert.equal(actual, expected, pattern);
+          assert.equal(actual, expected, fixture + ' => ' + pattern);
         });
       });
     });
